# ListUpstreamGroupMapping

List of upstream group mappings
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**upstream_group_mapping** | [**list[UpstreamGroupMapping]**](UpstreamGroupMapping.md) | List of upstream group mapping for a given issuer | 
**limit** | **int** | Limit of upstream group mappings in the response | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


